==> zio-aws-mediapackage_2.13-5.17.184.1-sources.jar: zio/aws/mediapackage/model/Profile.scala <==
package zio.aws.mediapackage.model
import scala.jdk.CollectionConverters._
sealed trait Profile {
  def unwrap: software.amazon.awssdk.services.mediapackage.model.Profile
}
object Profile {
  def wrap(
      value: software.amazon.awssdk.services.mediapackage.model.Profile
  ): zio.aws.mediapackage.model.Profile = value match {
    case software.amazon.awssdk.services.mediapackage.model.Profile.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.mediapackage.model.Profile.NONE =>
      val r = NONE
      r
    case software.amazon.awssdk.services.mediapackage.model.Profile.HBBTV_1_5 =>
      val r = HBBTV_1_5
      r
    case software.amazon.awssdk.services.mediapackage.model.Profile.HYBRIDCAST =>
      val r = HYBRIDCAST
      r
  }
  case object unknownToSdkVersion extends zio.aws.mediapackage.model.Profile {
    override def unwrap
        : software.amazon.awssdk.services.mediapackage.model.Profile =
      software.amazon.awssdk.services.mediapackage.model.Profile.UNKNOWN_TO_SDK_VERSION
  }
  case object NONE extends zio.aws.mediapackage.model.Profile {
    override def unwrap
        : software.amazon.awssdk.services.mediapackage.model.Profile =
      software.amazon.awssdk.services.mediapackage.model.Profile.NONE
  }
  case object HBBTV_1_5 extends zio.aws.mediapackage.model.Profile {
    override def unwrap
        : software.amazon.awssdk.services.mediapackage.model.Profile =
      software.amazon.awssdk.services.mediapackage.model.Profile.HBBTV_1_5
  }
  case object HYBRIDCAST extends zio.aws.mediapackage.model.Profile {
    override def unwrap
        : software.amazon.awssdk.services.mediapackage.model.Profile =
      software.amazon.awssdk.services.mediapackage.model.Profile.HYBRIDCAST
  }
}

==> zio-aws-mediapackage_2.13-5.20.7.2-sources.jar: zio/aws/mediapackage/model/Profile.scala <==
package zio.aws.mediapackage.model
import scala.jdk.CollectionConverters._
sealed trait Profile {
  def unwrap: software.amazon.awssdk.services.mediapackage.model.Profile
}
object Profile {
  def wrap(
      value: software.amazon.awssdk.services.mediapackage.model.Profile
  ): zio.aws.mediapackage.model.Profile = value match {
    case software.amazon.awssdk.services.mediapackage.model.Profile.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.mediapackage.model.Profile.NONE =>
      val r = NONE
      r
    case software.amazon.awssdk.services.mediapackage.model.Profile.HBBTV_1_5 =>
      val r = HBBTV_1_5
      r
    case software.amazon.awssdk.services.mediapackage.model.Profile.HYBRIDCAST =>
      val r = HYBRIDCAST
      r
    case software.amazon.awssdk.services.mediapackage.model.Profile.DVB_DASH_2014 =>
      val r = DVB_DASH_2014
      r
  }
  case object unknownToSdkVersion extends zio.aws.mediapackage.model.Profile {
    override def unwrap
        : software.amazon.awssdk.services.mediapackage.model.Profile =
      software.amazon.awssdk.services.mediapackage.model.Profile.UNKNOWN_TO_SDK_VERSION
  }
  case object NONE extends zio.aws.mediapackage.model.Profile {
    override def unwrap
        : software.amazon.awssdk.services.mediapackage.model.Profile =
      software.amazon.awssdk.services.mediapackage.model.Profile.NONE
  }
  case object HBBTV_1_5 extends zio.aws.mediapackage.model.Profile {
    override def unwrap
        : software.amazon.awssdk.services.mediapackage.model.Profile =
      software.amazon.awssdk.services.mediapackage.model.Profile.HBBTV_1_5
  }
  case object HYBRIDCAST extends zio.aws.mediapackage.model.Profile {
    override def unwrap
        : software.amazon.awssdk.services.mediapackage.model.Profile =
      software.amazon.awssdk.services.mediapackage.model.Profile.HYBRIDCAST
  }
  case object DVB_DASH_2014 extends zio.aws.mediapackage.model.Profile {
    override def unwrap
        : software.amazon.awssdk.services.mediapackage.model.Profile =
      software.amazon.awssdk.services.mediapackage.model.Profile.DVB_DASH_2014
  }
}
